@@ -48,6 +48,10 @@ public:
 		return write(str.c_str(), str.length());
 	};
 
+	DWORD getLastErrorCode() {
+		return _dwErrorCode;
+	};
+
 private:
 	HANDLE	_hFile		{INVALID_HANDLE_VALUE};
 	bool	_written	{false};
@@ -56,4 +60,6 @@ private:
 	const DWORD _accessParam  { GENERIC_READ | GENERIC_WRITE };
 	const DWORD _shareParam   { FILE_SHARE_READ | FILE_SHARE_WRITE };
 	const DWORD _attribParam  { FILE_ATTRIBUTE_NORMAL };
+
+	DWORD _dwErrorCode{ NO_ERROR };
 };
