@@ -420,9 +420,9 @@ BOOL Notepad_plus::notify(SCNotification *notification)
 			{
 				if (nppGui._smartHiliteOnAnotherView)
 				{
-					wchar_t selectedText[1024];
-					_pEditView->getGenericSelectedText(selectedText, sizeof(selectedText) / sizeof(wchar_t), false);
-					_smartHighlighter.highlightViewWithWord(notifyView, selectedText);
+					auto selectedText = _pEditView->getSelectedTextToWChar(false);
+					if (selectedText)
+						_smartHighlighter.highlightViewWithWord(notifyView, selectedText);
 				}
 				break;
 			}
@@ -1092,7 +1092,8 @@ BOOL Notepad_plus::notify(SCNotification *notification)
 			bool isSysReadOnly = buf->getFileReadOnly();
 			bool isInaccessible = buf->isInaccessible();
 			bool isUntitled = buf->isUntitled();
-			_tabPopupMenu.enableItem(IDM_EDIT_TOGGLEREADONLY, !isSysReadOnly && !buf->isMonitoringOn());
+			_tabPopupMenu.enableItem(IDM_EDIT_TOGGLEREADONLY, !isSysReadOnly && !buf->isMonitoringOn() &&
+				!(nppParam.getNppGUI()._isFullReadOnlySavingForbidden));
 			if (isInaccessible || isUntitled)
 			{
 				_tabPopupMenu.checkItem(IDM_EDIT_TOGGLESYSTEMREADONLY, false);
