@@ -65,6 +65,15 @@ namespace // anonymous
 		return defvalue; // fallback unknown
 	}
 
+	// local helper to get the current system time in milliseconds since Unix epoch (January 1, 1970)
+	ULONGLONG GetUnixSysTimeInMilliseconds()
+	{
+		FILETIME ft;
+		::GetSystemTimeAsFileTime(&ft); // 100-nanosecond intervals since January 1, 1601 (UTC)
+		ULONGLONG ullTime = (((ULONGLONG)ft.dwHighDateTime) << 32) | ft.dwLowDateTime;
+		const ULONGLONG EPOCH_DIFF = 116444736000000000ULL; // difference between Jan 1, 1601 and Jan 1, 1970 in 100-ns intervals
+		return (ullTime - EPOCH_DIFF) / 10000; // subtract the diff and convert to milliseconds
+	}
 } // anonymous namespace
 
 using namespace std;
@@ -84,6 +93,9 @@ Buffer::Buffer(FileManager * pManager, BufferID id, Document doc, DocFileStatus
 
 	_currentStatus = type;
 
+	if (nppParamInst.getNppGUI()._isFullReadOnly || nppParamInst.getNppGUI()._isFullReadOnlySavingForbidden)
+		_isUserReadOnly = true; // preset for the FileManager loadFile(), newEmptyDocument() and bufferFromDocument() funcs
+
 	setFileName(fileName);
 	updateTimeStamp();
 	checkFileState();
@@ -733,6 +745,16 @@ bool Buffer::allowClickableLink() const
 	return (!_isLargeFile || nppGui._largeFileRestriction._allowClickableLink) || !nppGui._largeFileRestriction._isEnabled;
 }
 
+void Buffer::setUserReadOnly(bool ro)
+{
+	if (ro != true && NppParameters::getInstance().getNppGUI()._isFullReadOnlySavingForbidden)
+		return; // full read-only saving forbidden mode active, refuse to cease the R/O state
+
+	_isUserReadOnly = ro;
+	doNotify(BufferChangeReadonly);
+}
+
+
 //filemanager
 
 FileManager::~FileManager()
@@ -1070,21 +1092,23 @@ bool FileManager::reloadBufferDeferred(BufferID id)
 
 bool FileManager::deleteFile(BufferID id)
 {
+	if (id == BUFFER_INVALID)
+		return false;
+
 	const Buffer* buf = getBufferByID(id);
 	wstring fileNamePath = buf->getFullPathName();
+	if (!doesFileExist(fileNamePath.c_str()))
+		return false;
 
 	// Make sure to form a string with double '\0' terminator.
 	fileNamePath.append(1, '\0');
 
-	if (!doesFileExist(fileNamePath.c_str()))
-		return false;
-
 	SHFILEOPSTRUCT fileOpStruct = {};
 	fileOpStruct.hwnd = NULL;
 	fileOpStruct.pFrom = fileNamePath.c_str();
 	fileOpStruct.pTo = NULL;
 	fileOpStruct.wFunc = FO_DELETE;
-	fileOpStruct.fFlags = FOF_ALLOWUNDO;
+	fileOpStruct.fFlags = FOF_ALLOWUNDO | FOF_NOCONFIRMATION; // FOF_NOCONFIRMATION - prevent possible redundant shell-dlg (Notepad++ uses its own delete-confirmation dlg)
 	fileOpStruct.fAnyOperationsAborted = false;
 	fileOpStruct.hNameMappings         = NULL;
 	fileOpStruct.lpszProgressTitle     = NULL;
@@ -1093,13 +1117,31 @@ bool FileManager::deleteFile(BufferID id)
 }
 
 
-bool FileManager::moveFile(BufferID id, const wchar_t * newFileName)
+bool FileManager::moveFile(BufferID id, const wchar_t* newFileName)
 {
-	Buffer* buf = getBufferByID(id);
-	const wchar_t *fileNamePath = buf->getFullPathName();
-	if (::MoveFileEx(fileNamePath, newFileName, MOVEFILE_REPLACE_EXISTING | MOVEFILE_COPY_ALLOWED | MOVEFILE_WRITE_THROUGH) == 0)
+	if (id == BUFFER_INVALID)
 		return false;
 
+	Buffer* buf = getBufferByID(id);
+	const wchar_t* fileNamePath = buf->getFullPathName();
+	if (!::MoveFileExW(fileNamePath, newFileName, MOVEFILE_REPLACE_EXISTING | MOVEFILE_COPY_ALLOWED | MOVEFILE_WRITE_THROUGH))
+	{
+		if (::GetLastError() != ERROR_ACCESS_DENIED)
+			return false;
+
+		// ERROR_ACCESS_DENIED, try to move elevated
+		// (notepad++.exe #UAC-MOVEFILE# original_file_path new_file_path)
+		wstring strCmdLineParams = NPP_UAC_MOVEFILE_SIGN;
+		strCmdLineParams += L" \"";
+		strCmdLineParams += fileNamePath;
+		strCmdLineParams += L"\" \"";
+		strCmdLineParams += newFileName;
+		strCmdLineParams += L"\"";
+		DWORD dwNppUacOpError = invokeNppUacOp(strCmdLineParams);
+		if (dwNppUacOpError != NO_ERROR)
+			return false;
+	}
+
 	buf->setFileName(newFileName);
 	return true;
 }
@@ -1320,10 +1362,18 @@ SavingStatus FileManager::saveBuffer(BufferID id, const wchar_t* filename, bool
 {
 	std::lock_guard<std::mutex> lock(save_mutex);
 
+	if (NppParameters::getInstance().getNppGUI()._isFullReadOnlySavingForbidden)
+	{
+		// safety check
+		// - this code part can be reached in full-read-only mode e.g. when have opened a previous session
+		//   with some dirty (snapshot backed-up) file(s) and use the SaveAll
+		return SavingStatus::FullReadOnlySavingForbidden;
+	}
+
 	Buffer* buffer = getBufferByID(id);
 	bool isHiddenOrSys = false;
 
-	wchar_t fullpath[MAX_PATH] = { 0 };
+	wchar_t fullpath[MAX_PATH]{};
 	if (isWin32NamespacePrefixedFileName(filename))
 	{
 		// use directly the raw file name, skip the GetFullPathName WINAPI
@@ -1338,7 +1388,7 @@ SavingStatus FileManager::saveBuffer(BufferID id, const wchar_t* filename, bool
 		}
 	}
 	
-	wchar_t dirDest[MAX_PATH];
+	wchar_t dirDest[MAX_PATH]{};
 	wcscpy_s(dirDest, MAX_PATH, fullpath);
 	::PathRemoveFileSpecW(dirDest);
 
@@ -1379,105 +1429,137 @@ SavingStatus FileManager::saveBuffer(BufferID id, const wchar_t* filename, bool
 
 	int encoding = buffer->getEncoding();
 
-	if (UnicodeConvertor.openFile(fullpath))
+	wstring strTempFile = L"";
+	if (!UnicodeConvertor.openFile(fullpath))
 	{
-		_pscratchTilla->execute(SCI_SETDOCPOINTER, 0, buffer->_doc);	//generate new document
+		if (NppParameters::getInstance().isEndSessionCritical())
+			return SavingStatus::SaveOpenFailed; // cannot continue to the UAC-prompt at the Windows logoff/reboot/shutdown time
 
-		size_t lengthDoc = _pscratchTilla->getCurrentDocLen();
-		char* buf = (char*)_pscratchTilla->execute(SCI_GETCHARACTERPOINTER);	//to get characters directly from Scintilla buffer
-		bool isWrittenSuccessful = false;
+		if (UnicodeConvertor.getLastFileErrorState() != ERROR_ACCESS_DENIED)
+			return SavingStatus::SaveOpenFailed; // cannot be solved by the UAC-prompt
 
-		if (encoding == -1) //no special encoding; can be handled directly by Utf8_16_Write
-		{
-			isWrittenSuccessful = UnicodeConvertor.writeFile(buf, lengthDoc);
-			if (lengthDoc == 0)
-				isWrittenSuccessful = true;
-		}
-		else
-		{
-			if (lengthDoc == 0)
-			{
-				isWrittenSuccessful = UnicodeConvertor.writeFile(buf, 0);
-			}
-			else
-			{
-				WcharMbcsConvertor& wmc = WcharMbcsConvertor::getInstance();
-				size_t grabSize = 0;
-				for (size_t i = 0; i < lengthDoc; i += grabSize)
-				{
-					grabSize = lengthDoc - i;
-					if (grabSize > blockSize)
-						grabSize = blockSize;
+		// ERROR_ACCESS_DENIED, swap to temporary file copy for the UAC elevation way
 
-					int newDataLen = 0;
-					int incompleteMultibyteChar = 0;
-					const char* newData = wmc.encode(SC_CP_UTF8, encoding, buf + i, static_cast<int>(grabSize), &newDataLen, &incompleteMultibyteChar);
-					grabSize -= incompleteMultibyteChar;
-					isWrittenSuccessful = UnicodeConvertor.writeFile(newData, newDataLen);
-				}
-			}
-		}
+		wchar_t wszBuf[MAX_PATH + 1]{};
+		if (::GetTempPath(MAX_PATH, wszBuf) == 0)
+			return SavingStatus::SaveOpenFailed; // cannot continue
 
-		UnicodeConvertor.closeFile();
+		strTempFile = wszBuf;
+		strTempFile += L"npp-" + std::to_wstring(GetUnixSysTimeInMilliseconds()) + L".tmp"; // make unique temporary filename
+		if (!UnicodeConvertor.openFile(strTempFile.c_str()))
+			return SavingStatus::SaveOpenFailed; // cannot continue, weird
+	}
 
-		// Error, we didn't write the entire document to disk.
-		if (!isWrittenSuccessful)
-		{
-			_pscratchTilla->execute(SCI_SETDOCPOINTER, 0, _scratchDocDefault);
-			return SavingStatus::SaveWritingFailed;
-		}
+	_pscratchTilla->execute(SCI_SETDOCPOINTER, 0, buffer->_doc);	//generate new document
 
-		if (isHiddenOrSys)
-			::SetFileAttributes(fullpath, attributes.dwFileAttributes);
+	size_t lengthDoc = _pscratchTilla->getCurrentDocLen();
+	char* buf = (char*)_pscratchTilla->execute(SCI_GETCHARACTERPOINTER);	//to get characters directly from Scintilla buffer
+	bool isWrittenSuccessful = false;
 
-		if (isCopy) // "Save a Copy As..." command
-		{
-			unsigned long MODEVENTMASK_ON = NppParameters::getInstance().getScintillaModEventMask();
-			_pscratchTilla->execute(SCI_SETMODEVENTMASK, MODEVENTMASK_OFF);
-			_pscratchTilla->execute(SCI_SETDOCPOINTER, 0, _scratchDocDefault);
-			_pscratchTilla->execute(SCI_SETMODEVENTMASK, MODEVENTMASK_ON);
-			return SavingStatus::SaveOK;	//all done - we don't change the current buffer's path to "fullpath", since it's "Save a Copy As..." action.
-		}
-
-		buffer->setFileName(fullpath);
-
-		// if not a large file and language is normal text (not defined)
-		// we may try determine its language from its content 
-		if (!buffer->isLargeFile() && buffer->_lang == L_TEXT)
-		{
-			LangType detectedLang = detectLanguageFromTextBeginning((unsigned char*)buf, lengthDoc);
-
-			// if a language is detected from the content
-			if (detectedLang != L_TEXT)
-			{
-				buffer->_lang = detectedLang;
-				buffer->doNotify(BufferChangeFilename | BufferChangeTimestamp | BufferChangeLanguage);
-			}
-		}
-		buffer->setDirty(false);
-		buffer->setUnsync(false);
-		buffer->setSavePointDirty(false);
-		buffer->setStatus(DOC_REGULAR);
-		buffer->checkFileState();
-
-
-		_pscratchTilla->execute(SCI_SETSAVEPOINT);
-		_pscratchTilla->execute(SCI_SETDOCPOINTER, 0, _scratchDocDefault);
-
-		wstring backupFilePath = buffer->getBackupFileName();
-		if (!backupFilePath.empty())
-		{
-			// delete backup file
-			buffer->setBackupFileName(wstring());
-			::DeleteFile(backupFilePath.c_str());
-		}
-
-		return SavingStatus::SaveOK;
+	if (encoding == -1) //no special encoding; can be handled directly by Utf8_16_Write
+	{
+		isWrittenSuccessful = UnicodeConvertor.writeFile(buf, lengthDoc);
+		if (lengthDoc == 0)
+			isWrittenSuccessful = true;
 	}
 	else
 	{
-		return SavingStatus::SaveOpenFailed;
+		if (lengthDoc == 0)
+		{
+			isWrittenSuccessful = UnicodeConvertor.writeFile(buf, 0);
+		}
+		else
+		{
+			WcharMbcsConvertor& wmc = WcharMbcsConvertor::getInstance();
+			size_t grabSize = 0;
+			for (size_t i = 0; i < lengthDoc; i += grabSize)
+			{
+				grabSize = lengthDoc - i;
+				if (grabSize > blockSize)
+					grabSize = blockSize;
+
+				int newDataLen = 0;
+				int incompleteMultibyteChar = 0;
+				const char* newData = wmc.encode(SC_CP_UTF8, encoding, buf + i, static_cast<int>(grabSize), &newDataLen, &incompleteMultibyteChar);
+				grabSize -= incompleteMultibyteChar;
+				isWrittenSuccessful = UnicodeConvertor.writeFile(newData, newDataLen);
+			}
+		}
 	}
+
+	UnicodeConvertor.closeFile();
+
+	if (isHiddenOrSys && strTempFile.empty())
+		::SetFileAttributes(fullpath, attributes.dwFileAttributes);
+
+	// Error, we didn't write the entire document to disk.
+	if (!isWrittenSuccessful)
+	{
+		_pscratchTilla->execute(SCI_SETDOCPOINTER, 0, _scratchDocDefault);
+		if (!strTempFile.empty())
+			::DeleteFileW(strTempFile.c_str());
+		return SavingStatus::SaveWritingFailed;
+	}
+
+	if (!strTempFile.empty())
+	{
+		// elevated saving/overwriting of the original file by the help of the tempfile
+		// (notepad++.exe #UAC-SAVE# temp_file_path dest_file_path)
+		wstring strCmdLineParams = NPP_UAC_SAVE_SIGN;
+		strCmdLineParams += L" \"" + strTempFile + L"\" \"";
+		strCmdLineParams += fullpath;
+		strCmdLineParams += L"\"";
+		DWORD dwNppUacOpError = invokeNppUacOp(strCmdLineParams);
+		if (dwNppUacOpError != NO_ERROR)
+		{
+			::DeleteFileW(strTempFile.c_str()); // ensure no failed op remnant
+			::SetLastError(dwNppUacOpError); // set that as our current thread one for reporting later
+			return SavingStatus::SaveWritingFailed;
+		}
+	}
+
+	if (isCopy) // "Save a Copy As..." command
+	{
+		unsigned long MODEVENTMASK_ON = NppParameters::getInstance().getScintillaModEventMask();
+		_pscratchTilla->execute(SCI_SETMODEVENTMASK, MODEVENTMASK_OFF);
+		_pscratchTilla->execute(SCI_SETDOCPOINTER, 0, _scratchDocDefault);
+		_pscratchTilla->execute(SCI_SETMODEVENTMASK, MODEVENTMASK_ON);
+		return SavingStatus::SaveOK;	//all done - we don't change the current buffer's path to "fullpath", since it's "Save a Copy As..." action.
+	}
+
+	buffer->setFileName(fullpath);
+
+	// if not a large file and language is normal text (not defined)
+	// we may try determine its language from its content 
+	if (!buffer->isLargeFile() && buffer->_lang == L_TEXT)
+	{
+		LangType detectedLang = detectLanguageFromTextBeginning((unsigned char*)buf, lengthDoc);
+
+		// if a language is detected from the content
+		if (detectedLang != L_TEXT)
+		{
+			buffer->_lang = detectedLang;
+			buffer->doNotify(BufferChangeFilename | BufferChangeTimestamp | BufferChangeLanguage);
+		}
+	}
+	buffer->setDirty(false);
+	buffer->setUnsync(false);
+	buffer->setSavePointDirty(false);
+	buffer->setStatus(DOC_REGULAR);
+	buffer->checkFileState();
+
+	_pscratchTilla->execute(SCI_SETSAVEPOINT);
+	_pscratchTilla->execute(SCI_SETDOCPOINTER, 0, _scratchDocDefault);
+
+	wstring backupFilePath = buffer->getBackupFileName();
+	if (!backupFilePath.empty())
+	{
+		// delete backup file
+		buffer->setBackupFileName(wstring());
+		::DeleteFile(backupFilePath.c_str());
+	}
+
+	return SavingStatus::SaveOK;
 }
 
 size_t FileManager::nextUntitledNewNumber() const
@@ -1529,17 +1611,21 @@ size_t FileManager::nextUntitledNewNumber() const
 
 BufferID FileManager::newEmptyDocument()
 {
-	wstring newTitle = ((NppParameters::getInstance()).getNativeLangSpeaker())->getLocalizedStrFromID("tab-untitled-string", UNTITLED_STR);
+	NppParameters& nppParams = NppParameters::getInstance();
 
-	wchar_t nb[10];
+	wstring newTitle = (nppParams.getNativeLangSpeaker())->getLocalizedStrFromID("tab-untitled-string", UNTITLED_STR);
+
+	wchar_t nb[10]{};
 	wsprintf(nb, L"%d", static_cast<int>(nextUntitledNewNumber()));
 	newTitle += nb;
 
 	Document doc = static_cast<Document>(_pscratchTilla->execute(SCI_CREATEDOCUMENT, 0, SC_DOCUMENTOPTION_TEXT_LARGE)); // this already sets a reference for filemanager
+	if (doc == 0) // if SCI_CREATEDOCUMENT fails, 0 is returned
+		return BUFFER_INVALID;
+
 	Buffer* newBuf = new Buffer(this, _nextBufferID, doc, DOC_UNNAMED, newTitle.c_str(), false);
 
-	NppParameters& nppParamInst = NppParameters::getInstance();
-	const NewDocDefaultSettings& ndds = (nppParamInst.getNppGUI()).getNewDocDefaultSettings();
+	const NewDocDefaultSettings& ndds = (nppParams.getNppGUI()).getNewDocDefaultSettings();
 	newBuf->_lang = ndds._lang;
 
 	BufferID id = newBuf;
@@ -1587,9 +1673,13 @@ BufferID FileManager::newPlaceholderDocument(const wchar_t* missingFilename, int
 		return BUFFER_INVALID;
 
 	BufferID buf = MainFileManager.newEmptyDocument();
+	if (buf == BUFFER_INVALID)
+		return BUFFER_INVALID;
+
 	_pNotepadPlus->loadBufferIntoView(buf, whichOne);
 	buf->setFileName(missingFilename);
 	buf->_currentStatus = DOC_INACCESSIBLE;
+
 	return buf;
 }
 
@@ -2020,10 +2110,26 @@ BufferID FileManager::getBufferFromDocument(Document doc)
 }
 
 
-bool FileManager::createEmptyFile(const wchar_t * path)
+bool FileManager::createEmptyFile(const wchar_t* path)
 {
 	Win32_IO_File file(path);
-	return file.isOpened();
+	if (!file.isOpened())
+	{
+		if (file.getLastErrorCode() != ERROR_ACCESS_DENIED)
+			return false;
+
+		// ERROR_ACCESS_DENIED, try the same but elevated
+		// (notepad++.exe #UAC-CREATEEMPTYFILE# new_empty_file_path)
+		wstring strCmdLineParams = NPP_UAC_CREATEEMPTYFILE_SIGN;
+		strCmdLineParams += L" \"";
+		strCmdLineParams += path;
+		strCmdLineParams += L"\"";
+		DWORD dwNppUacOpError = invokeNppUacOp(strCmdLineParams);
+		if (dwNppUacOpError != NO_ERROR)
+			return false;
+	}
+
+	return true;
 }
 
 
