@@ -46,8 +46,8 @@ u78 Utf8_16_Read::utf8_7bits_8bits()
 {
 	int rv = 1;
 	int ASCII7only = 1;
-	utf8 *sx	= (utf8 *)m_pBuf;
-	utf8 *endx	= sx + m_nLen;
+	utf8* sx = (utf8 *)m_pBuf;
+	utf8* endx = sx + m_nLen;
 
 	while (sx<endx)
 	{
@@ -292,6 +292,7 @@ Utf8_16_Write::Utf8_16_Write()
 	m_pNewBuf = NULL;
 	m_bFirstWrite = true;
 	m_nBufSize = 0;
+	m_dwLastFileError = NO_ERROR;
 }
 
 Utf8_16_Write::~Utf8_16_Write()
@@ -299,13 +300,16 @@ Utf8_16_Write::~Utf8_16_Write()
 	closeFile();
 }
 
-bool Utf8_16_Write::openFile(const TCHAR *name)
+bool Utf8_16_Write::openFile(const wchar_t *name)
 {
-	m_pFile = std::make_unique<Win32_IO_File>(name);
+	m_dwLastFileError = NO_ERROR;
 
+	m_pFile = std::make_unique<Win32_IO_File>(name);
 	if (!m_pFile)
 		return false;
 
+	m_dwLastFileError = m_pFile->getLastErrorCode();
+
 	if (!m_pFile->isOpened())
 	{
 		m_pFile = nullptr;
@@ -319,78 +323,85 @@ bool Utf8_16_Write::openFile(const TCHAR *name)
 
 bool Utf8_16_Write::writeFile(const void* p, size_t _size)
 {
-    // no file open
+	m_dwLastFileError = NO_ERROR;
+
+	// no file open
 	if (!m_pFile)
-    {
 		return false;
-	}
 
 	if (m_bFirstWrite)
-    {
-        switch (m_eEncoding)
-        {
-            case uniUTF8:
+	{
+		switch (m_eEncoding)
+		{
+			case uniUTF8:
 			{
-                if (!m_pFile->write(k_Boms[m_eEncoding], 3))
-					return false;
-            }
-			break;
-
-            case uni16BE:
-            case uni16LE:
-			{
-				if (!m_pFile->write(k_Boms[m_eEncoding], 2))
+				if (!m_pFile->write(k_Boms[m_eEncoding], 3))
+				{
+					m_dwLastFileError = m_pFile->getLastErrorCode();
 					return false;
+				}
 			}
 			break;
 
-            default:
+			case uni16BE:
+			case uni16LE:
+			{
+				if (!m_pFile->write(k_Boms[m_eEncoding], 2))
+				{
+					m_dwLastFileError = m_pFile->getLastErrorCode();
+					return false;
+				}
+			}
+			break;
+
+			default:
 			{
 				// nothing to do
 			}
 			break;
-        }
+		}
 		m_bFirstWrite = false;
-    }
+	}
 
-    bool isOK = false;
+	bool isOK = false;
 
-    switch (m_eEncoding)
-    {
+	switch (m_eEncoding)
+	{
 		case uni7Bit:
-        case uni8Bit:
-        case uniCookie:
-        case uniUTF8:
+		case uni8Bit:
+		case uniCookie:
+		case uniUTF8:
 		{
-            // Normal write
+			// Normal write
 			if (m_pFile->write(p, _size))
 				isOK = true;
-
-        }
+			m_dwLastFileError = m_pFile->getLastErrorCode();
+		}
 		break;
 
-        case uni16BE_NoBOM:
-        case uni16LE_NoBOM:
-        case uni16BE:
-        case uni16LE:
+		case uni16BE_NoBOM:
+		case uni16LE_NoBOM:
+		case uni16BE:
+		case uni16LE:
 		{
-			static const unsigned int bufSize = 64*1024;
+			static const unsigned int bufSize = 64 * 1024;
 			utf16* buf = new utf16[bufSize];
-            
-            Utf8_Iter iter8;
-            iter8.set(static_cast<const ubyte*>(p), _size, m_eEncoding);
+
+			Utf8_Iter iter8;
+			iter8.set(static_cast<const ubyte*>(p), _size, m_eEncoding);
 
 			unsigned int bufIndex = 0;
 			while (iter8)
 			{
 				++iter8;
 				while ((bufIndex < bufSize) && iter8.canGet())
-					iter8.get(&buf [bufIndex++]);
+					iter8.get(&buf[bufIndex++]);
 
 				if (bufIndex == bufSize || !iter8)
 				{
 					if (!m_pFile->write(buf, bufIndex * sizeof(utf16)))
 					{
+						m_dwLastFileError = m_pFile->getLastErrorCode();
 						delete[] buf;
 						return 0;
 					}
@@ -399,15 +410,14 @@ bool Utf8_16_Write::writeFile(const void* p, size_t _size)
 			}
 			isOK = true;
 			delete[] buf;
-            
-        }
+		}
 		break;
-        
-		default:
-            break;
-    }
 
-    return isOK;
+		default:
+			break;
+	}
+
+	return isOK;
 }
 
 
@@ -506,7 +516,15 @@ void Utf8_16_Write::closeFile()
 	}
 
 	if (m_pFile)
+	{
+		m_pFile->close(); // explicit closing for getting the possible flushing/closing error code
+		m_dwLastFileError = m_pFile->getLastErrorCode();
 		m_pFile = nullptr;
+	}
+	else
+	{
+		m_dwLastFileError = NO_ERROR;
+	}
 }
 
 
