@@ -474,6 +474,9 @@
 #define IDC_INSELECTION_THRESHOLD_EDIT                 6911
 #define IDC_INSELECTION_THRESH_QUESTION_BUTTON         6912
 #define IDC_CHECK_FILL_DIR_FIELD_FROM_ACTIVE_DOC       6913
+#define IDC_FILLFINDWHAT_THRESH_QUESTION_BUTTON        6914
+#define IDC_FILLFINDWHAT_THRESHOLD_EDIT                6915
+#define IDC_FILLFINDWHAT_THRESHOLD_STATIC              6916
 
 #define IDD_PREFERENCE_SUB_DARKMODE                    7100
 
